powered by
This functions allows to obtain the transition probability matrices for a specific value of x, considering the estimates obtained from mmcx().
mmcx()
MMC_tpm(s, x, value = max(x), result)
The function returns a numerical array with the probability transition matrices for each equation
numerical matrix with categorical data sequences
exogeneous variable
fixed value of x
result from the function mmcx()
Carolina Vasconcelos and Bruno Damásio
data(stockreturns) s <- cbind(stockreturns$sp500, stockreturns$djia) x <- stockreturns$spread_1 res <- mmcx(s, x, initial = c(1, 1)) tpm <- MMC_tpm(s, x, value = max(x), result = res)
Run the code above in your browser using DataLab